==> mongodb-store-5.1.5.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

### [4.0.30](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.29...@furystack/mongodb-store@4.0.30) (2022-02-16)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.29](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.28...@furystack/mongodb-store@4.0.29) (2022-02-02)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.28](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.26...@furystack/mongodb-store@4.0.28) (2022-01-10)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.27](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.26...@furystack/mongodb-store@4.0.27) (2022-01-10)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.26](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.25...@furystack/mongodb-store@4.0.26) (2021-12-20)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.25](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.24...@furystack/mongodb-store@4.0.25) (2021-12-08)


### 🐛 Bug Fixes

* **@furystack/mongodb-store:** Connection state lock on dispose ([c992683](https://github.com/furystack/core/commit/c9926832b142f187a6515a463abacdbc77537598))




### [4.0.24](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.23...@furystack/mongodb-store@4.0.24) (2021-11-30)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.23](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.22...@furystack/mongodb-store@4.0.23) (2021-11-29)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.22](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.21...@furystack/mongodb-store@4.0.22) (2021-11-19)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.21](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.20...@furystack/mongodb-store@4.0.21) (2021-11-09)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.20](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.19...@furystack/mongodb-store@4.0.20) (2021-10-15)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.19](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.18...@furystack/mongodb-store@4.0.19) (2021-10-05)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.18](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.17...@furystack/mongodb-store@4.0.18) (2021-09-16)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.17](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.16...@furystack/mongodb-store@4.0.17) (2021-08-27)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.16](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.15...@furystack/mongodb-store@4.0.16) (2021-08-19)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.15](https://github.com/furystack/core/compare/@furystack/mongodb-store@3.1.21...@furystack/mongodb-store@4.0.15) (2021-08-19)

**Note:** Version bump only for package @furystack/mongodb-store






### [4.0.14](https://github.com/furystack/core/compare/@furystack/mongodb-store@3.1.21...@furystack/mongodb-store@4.0.14) (2021-07-30)

**Note:** Version bump only for package @furystack/mongodb-store

==> mongodb-store-10.0.14.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

### [4.0.30](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.29...@furystack/mongodb-store@4.0.30) (2022-02-16)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.29](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.28...@furystack/mongodb-store@4.0.29) (2022-02-02)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.28](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.26...@furystack/mongodb-store@4.0.28) (2022-01-10)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.27](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.26...@furystack/mongodb-store@4.0.27) (2022-01-10)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.26](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.25...@furystack/mongodb-store@4.0.26) (2021-12-20)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.25](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.24...@furystack/mongodb-store@4.0.25) (2021-12-08)

### 🐛 Bug Fixes

- **@furystack/mongodb-store:** Connection state lock on dispose ([c992683](https://github.com/furystack/core/commit/c9926832b142f187a6515a463abacdbc77537598))

### [4.0.24](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.23...@furystack/mongodb-store@4.0.24) (2021-11-30)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.23](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.22...@furystack/mongodb-store@4.0.23) (2021-11-29)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.22](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.21...@furystack/mongodb-store@4.0.22) (2021-11-19)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.21](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.20...@furystack/mongodb-store@4.0.21) (2021-11-09)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.20](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.19...@furystack/mongodb-store@4.0.20) (2021-10-15)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.19](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.18...@furystack/mongodb-store@4.0.19) (2021-10-05)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.18](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.17...@furystack/mongodb-store@4.0.18) (2021-09-16)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.17](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.16...@furystack/mongodb-store@4.0.17) (2021-08-27)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.16](https://github.com/furystack/core/compare/@furystack/mongodb-store@4.0.15...@furystack/mongodb-store@4.0.16) (2021-08-19)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.15](https://github.com/furystack/core/compare/@furystack/mongodb-store@3.1.21...@furystack/mongodb-store@4.0.15) (2021-08-19)

**Note:** Version bump only for package @furystack/mongodb-store

### [4.0.14](https://github.com/furystack/core/compare/@furystack/mongodb-store@3.1.21...@furystack/mongodb-store@4.0.14) (2021-07-30)

**Note:** Version bump only for package @furystack/mongodb-store
